==> haskell-hjsmin-0.2.1-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hjsmin
version:              0.2.1
visibility:           public
id:                   hjsmin-0.2.1-1iEzrXIJQSpEcRa29oDTfZ
key:                  hjsmin-0.2.1-1iEzrXIJQSpEcRa29oDTfZ
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  9a6341978e00ab30809e81a641e7108c
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hjsmin
hs-libraries:         HShjsmin-0.2.1-1iEzrXIJQSpEcRa29oDTfZ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    language-javascript-0.7.1.0-HiOHhyJDgK67P9F1vxYDz text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsmin-0.2.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hjsmin
version:              0.2.1
visibility:           public
id:                   hjsmin-0.2.1-Ht7WRvZeGxs9vHimQKKkSZ
key:                  hjsmin-0.2.1-Ht7WRvZeGxs9vHimQKKkSZ
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  27ca6a67bcc3d5b458d05e1a30383b17
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hjsmin-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hjsmin
hs-libraries:         HShjsmin-0.2.1-Ht7WRvZeGxs9vHimQKKkSZ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    language-javascript-0.7.1.0-LJmc2kEkds4Li2riZTbkke text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
